# coding=utf-8

from utils.custom_modelviewset import CustomModelViewSet
from rest_framework.decorators import action
import json

from .models import OperationHelp
from utils.permission import IsAdministratorUser
from .serializer import OperationHelpSerializer
from apps.log.models import BizLog
from .filters import OperationHelpFilter
from django.db import transaction
from utils.exceptions import CustomError
from utils import response_ok, response_error


class OperationHelpViewSet(CustomModelViewSet):
    permission_classes = [IsAdministratorUser, ]
    queryset = OperationHelp.objects.filter()
    serializer_class = OperationHelpSerializer

    def filter_queryset(self, queryset):
        queryset = queryset.filter(tenant=self.request.user.employee.tenant)
        f = OperationHelpFilter(self.request.GET, queryset=queryset)
        return f.qs

    def perform_create(self, serializer):
        super(OperationHelpViewSet, self).perform_create(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        BizLog.objects.addnew(instance.tenant, self.request.user, BizLog.INSERT, u'添加运维帮助信息,id={}'.format(instance.id), validated_data)

    def perform_update(self, serializer):
        super(OperationHelpViewSet, self).perform_update(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        BizLog.objects.addnew(instance.tenant, self.request.user, BizLog.INSERT, u'修改运维帮助信息,id={}'.format(instance.id),
                              validated_data)
